#!/bin/bash
#
# Copyright (C) 2019 OX Software GmbH
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
source ${SCRIPT_DIR}/../lib/common.bash
source ${SCRIPT_DIR}/../lib/setup.bash

# INSTALL_FOO=false
# INSTALL_BAR=false

## Help text
show_usage() {
echo -n "
    --foo
    --bar <value>

"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    # --foo) # non value argument
    # INSTALL_FOO=true
    # shift
    # ;;
    # --bar) # argument with value 
    # INSTALL_BAR=true
    # BAR_VAL=$2
    # shift
    # shift
    # ;;
    *) # unknown option
    echo "Unknonwn option: $1"
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters


# 
# if [[ "${INSTALL_FOO}" = true  ]]; then
#     PACKAGES="${PACKAGES} "
# fi

# # 
# if [[ "${INSTALL_BAR}" = true  ]]; then
#     PACKAGES="${PACKAGES} "
# fi



if [[ "${DIST}" == "DebianBuster" ]]; then
    # echo "Adding adoptopenjdk.jfrog.io build key to apt ..."
    # wget -qO - https://adoptopenjdk.jfrog.io/adoptopenjdk/api/gpg/key/public | apt-key add -

    # add-apt-repository --yes https://adoptopenjdk.jfrog.io/adoptopenjdk/deb/

    # PACKAGES="adoptopenjdk-${JAVA_JDK_VERSION}-hotspot"


    # We have to use unstable sid packages for java8 jdk 
    echo "deb http://ftp.debian.org/debian sid main" > /etc/apt/sources.list.d/99debianunstable.list
    # set the current default release for packages to stable to avaoid upgrading to unstable packages
    # echo "APT::Default-Release \"stable\";" > /etc/apt/apt.conf.d/99defaultrelease
    apt-get update
    apt-get install --no-install-recommends -y openjdk-8-jdk

    rm /etc/apt/sources.list.d/99debianunstable.list
    apt-get update

else
    # In most cases the distribution will ship some java 8 packacges, for debian buster they have to be fetched from sid repositories
    exit 0
fi


